@@ -6,7 +6,6 @@ from pyspark.sql import SparkSession, Column, DataFrame
 from pyspark.sql.functions import col, hash
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -39,9 +38,8 @@ def test_auto_mapper_hash(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["age"],
-        hash(col("b.my_age"), col("b.last_name")).cast("string").alias("age"),
+    assert str(sql_expressions["age"]) == str(
+        hash(col("b.my_age"), col("b.last_name")).cast("string").alias("age")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
